==> ns3_3.41.orig.tar.bz2: ns-allinone-3.41/ns-3.41/src/applications/helper/udp-client-server-helper.cc <==
/*
 * Copyright (c) 2008 INRIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Mohamed Amine Ismail <amine.ismail@sophia.inria.fr>
 */
#include "udp-client-server-helper.h"

#include "ns3/string.h"
#include "ns3/udp-client.h"
#include "ns3/udp-server.h"
#include "ns3/udp-trace-client.h"
#include "ns3/uinteger.h"

namespace ns3
{

UdpServerHelper::UdpServerHelper()
{
    m_factory.SetTypeId(UdpServer::GetTypeId());
}

UdpServerHelper::UdpServerHelper(uint16_t port)
{
    m_factory.SetTypeId(UdpServer::GetTypeId());
    SetAttribute("Port", UintegerValue(port));
}

void
UdpServerHelper::SetAttribute(std::string name, const AttributeValue& value)
{
    m_factory.Set(name, value);
}

ApplicationContainer
UdpServerHelper::Install(NodeContainer c)
{
    ApplicationContainer apps;
    for (auto i = c.Begin(); i != c.End(); ++i)
    {
        Ptr<Node> node = *i;

        m_server = m_factory.Create<UdpServer>();
        node->AddApplication(m_server);
        apps.Add(m_server);
    }
    return apps;
}

Ptr<UdpServer>
UdpServerHelper::GetServer()
{
    return m_server;
}

UdpClientHelper::UdpClientHelper()
{
    m_factory.SetTypeId(UdpClient::GetTypeId());
}

UdpClientHelper::UdpClientHelper(Address address, uint16_t port)
{
    m_factory.SetTypeId(UdpClient::GetTypeId());
    SetAttribute("RemoteAddress", AddressValue(address));
    SetAttribute("RemotePort", UintegerValue(port));
}

UdpClientHelper::UdpClientHelper(Address address)
{
    m_factory.SetTypeId(UdpClient::GetTypeId());
    SetAttribute("RemoteAddress", AddressValue(address));
}

void
UdpClientHelper::SetAttribute(std::string name, const AttributeValue& value)
{
    m_factory.Set(name, value);
}

ApplicationContainer
UdpClientHelper::Install(NodeContainer c)
{
    ApplicationContainer apps;
    for (auto i = c.Begin(); i != c.End(); ++i)
    {
        Ptr<Node> node = *i;
        Ptr<UdpClient> client = m_factory.Create<UdpClient>();
        node->AddApplication(client);
        apps.Add(client);
    }
    return apps;
}

UdpTraceClientHelper::UdpTraceClientHelper()
{
    m_factory.SetTypeId(UdpTraceClient::GetTypeId());
}

UdpTraceClientHelper::UdpTraceClientHelper(Address address, uint16_t port, std::string filename)
{
    m_factory.SetTypeId(UdpTraceClient::GetTypeId());
    SetAttribute("RemoteAddress", AddressValue(address));
    SetAttribute("RemotePort", UintegerValue(port));
    SetAttribute("TraceFilename", StringValue(filename));
}

UdpTraceClientHelper::UdpTraceClientHelper(Address address, std::string filename)
{
    m_factory.SetTypeId(UdpTraceClient::GetTypeId());
    SetAttribute("RemoteAddress", AddressValue(address));
    SetAttribute("TraceFilename", StringValue(filename));
}

void
UdpTraceClientHelper::SetAttribute(std::string name, const AttributeValue& value)
{
    m_factory.Set(name, value);
}

ApplicationContainer
UdpTraceClientHelper::Install(NodeContainer c)
{
    ApplicationContainer apps;
    for (auto i = c.Begin(); i != c.End(); ++i)
    {
        Ptr<Node> node = *i;
        Ptr<UdpTraceClient> client = m_factory.Create<UdpTraceClient>();
        node->AddApplication(client);
        apps.Add(client);
    }
    return apps;
}

} // namespace ns3

==> ns3_3.42.orig.tar.bz2: ns-allinone-3.42/ns-3.42/src/applications/helper/udp-client-server-helper.cc <==
/*
 * Copyright (c) 2008 INRIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Mohamed Amine Ismail <amine.ismail@sophia.inria.fr>
 */

#include "udp-client-server-helper.h"

#include <ns3/string.h>
#include <ns3/uinteger.h>

namespace ns3
{

UdpServerHelper::UdpServerHelper()
    : ApplicationHelper(UdpServer::GetTypeId())
{
}

UdpServerHelper::UdpServerHelper(uint16_t port)
    : UdpServerHelper()
{
    SetAttribute("Port", UintegerValue(port));
}

UdpClientHelper::UdpClientHelper()
    : ApplicationHelper(UdpClient::GetTypeId())
{
}

UdpClientHelper::UdpClientHelper(const Address& address)
    : UdpClientHelper()
{
    SetAttribute("RemoteAddress", AddressValue(address));
}

UdpClientHelper::UdpClientHelper(const Address& address, uint16_t port)
    : UdpClientHelper(address)
{
    SetAttribute("RemotePort", UintegerValue(port));
}

UdpTraceClientHelper::UdpTraceClientHelper()
    : ApplicationHelper(UdpTraceClient::GetTypeId())
{
}

UdpTraceClientHelper::UdpTraceClientHelper(const Address& address, const std::string& filename)
    : UdpTraceClientHelper()
{
    SetAttribute("RemoteAddress", AddressValue(address));
    SetAttribute("TraceFilename", StringValue(filename));
}

UdpTraceClientHelper::UdpTraceClientHelper(const Address& address,
                                           uint16_t port,
                                           const std::string& filename)
    : UdpTraceClientHelper(address, filename)
{
    SetAttribute("RemotePort", UintegerValue(port));
}

} // namespace ns3
